@@ -22,4 +22,4 @@ def tojpg(imgPath: str):
     :param imgPath: 图片路径 | image path
     :return:
     """
-    Image.open(imgPath).save(imgPath + '.jpg')
+    Image.open(imgPath).convert("RGB").save(imgPath + '.jpg', quality=100)
